@@ -7,7 +7,9 @@ from auterioncli.commands.command_base import CliCommand
 from auterioncli.commands.app_sdk.environment import ensure_docker, ensure_mender_artifact
 from auterioncli.commands.app_sdk.slimify import slimify
 import subprocess
+import collections.abc
 import re
+import copy
 
 PLATFORM_ALIAS = {
     'skynode': 'linux/arm64',
@@ -15,6 +17,15 @@ PLATFORM_ALIAS = {
 }
 
 
+def deep_dict_update(d, u):
+    for k, v in u.items():
+        if isinstance(v, collections.abc.Mapping):
+            d[k] = deep_dict_update(d.get(k, {}), v)
+        else:
+            d[k] = v
+    return d
+
+
 def run_command(commands, cwd='.'):
     print(f'> Executing \'{" ".join(commands)}\'')
     result = subprocess.run(commands, cwd=cwd)
@@ -50,7 +61,6 @@ class AppBuildCommand(CliCommand):
 
         self._temp_dir = tempfile.mkdtemp()
         meta = self._load_metadata(args)
-        self._compose_from_meta(meta)
 
         image_path = self._generate_image(args, meta)
 
@@ -90,44 +100,64 @@ class AppBuildCommand(CliCommand):
 
         return meta
 
-    def _compose_from_meta(self, meta):
-        compose = {
-            'version': '3.7',
-            **meta['compose']
-        }
+    def _compose_for_building_from_meta(self, meta):
+        api_version = meta['auterion-api-version']
+        assert(0 <= api_version <= 1, f'Auterion API version {api_version} is not supported by this '
+                                      f'version of auterion-cli. Supported API versions are 0 and 1.')
+
+        compose = {}
+        if api_version == 0:
+            compose = {
+                'version': '3.7',
+                **meta['compose']
+            }
+        elif api_version == 1:
+            compose = {
+                'version': '3.7',
+                'services': {}
+            }
+            for name, service_config in meta['services'].items():
+                compose['services'][name] = {
+                    'build': service_config['build']
+                }
+            # api version 1 still allows for dict update
+            if 'compose-override' in meta:
+                deep_dict_update(compose, meta['compose-override'])
 
         for name, service in compose['services'].items():
             if 'image' not in service:
                 service['image'] = name + ':' + meta['app-version']
             service['container_name'] = name
             service['platform'] = PLATFORM_ALIAS.get(meta['target-platform'], meta['target-platform'])
-
-        compose_file = os.path.join(self._temp_dir, 'docker-compose.yml')
-        with open(compose_file, 'w') as f:
-            yaml.dump(compose, f)
+        return compose
 
     def _generate_image(self, args, meta):
-        # Generate build dif
+        # Generate build dir
         project_dir = args.project_dir
         build_dir = os.path.join(project_dir, 'build')
         if not os.path.exists(build_dir):
             os.mkdir(build_dir)
 
         target_file = os.path.join(build_dir, meta['app-name'] + '.tar')
+
+        # generate a minimal docker-compose file in temp dir for building using docker-compose
         compose_file = os.path.join(self._temp_dir, 'docker-compose.yml')
+        compose = self._compose_for_building_from_meta(meta)
+        with open(compose_file, 'w') as f:
+            yaml.dump(compose, f)
 
         if not args.skip_docker_build:
             # Just export the required images from the local docker
             target_platform = PLATFORM_ALIAS.get(meta['target-platform'], meta['target-platform'])
             run_command(['docker', 'compose', '-f', compose_file, 'build'], cwd=args.project_dir)
 
-            non_built_images = [v['image'] for k, v in meta['compose']['services'].items() if 'build' not in v]
+            non_built_images = [v['image'] for k, v in compose['services'].items() if 'build' not in v]
             if len(non_built_images) > 0:
                 print(f'Need to pull {len(non_built_images)} images for this build..')
                 for image in non_built_images:
                     run_command(['docker', 'pull', '--platform', target_platform, image])
 
-        images = [v['image'] for k, v in meta['compose']['services'].items()]
+        images = [v['image'] for k, v in compose['services'].items()]
         print('According to docker-compose, we have the following images:')
         for image in images:
             print(f'- {image}')
@@ -144,17 +174,36 @@ class AppBuildCommand(CliCommand):
         p.rename(target_name)
         return str(target_name)
 
+    def _generate_legacy_app_file(self, meta, app_file):
+        # add default settings for compose
+        compose = self._compose_for_building_from_meta(meta)
+        app_dict = copy.deepcopy(compose)
+        for name, service in app_dict['services'].items():
+            if 'restart' not in service:
+                service['restart'] = 'unless-stopped'
+            if 'network_mode' not in service:
+                service['network_mode'] = 'host'
+            if 'volumes' not in service:
+                service['volumes'] = [f'/data/app/{meta["app-name"]}/data:/data']
+            # older docker-compose get confused about the platform and build tags
+            if 'platform' in service:
+                del service['platform']
+            if 'build' in service:
+                del service['build']
+
+        with open(app_file, 'w') as fo:
+            yaml.dump(app_dict, fo)
+
     def _mender_package_app(self, args, meta, image_file):
         if not os.path.exists(image_file):
             error(f'Image {image_file} does not exist. Nothing to package. Aborting..')
 
         version = meta['app-version']
         name = meta['app-name']
-        device = meta['target-device'] if 'target-device' in meta else 'skynode'
+        device = meta['target-platform'] if 'target-platform' in meta else 'skynode'
         out_file = os.path.join(args.project_dir, 'build', name + '.auterionos')
 
         meta_file = os.path.join(args.project_dir, 'auterion-app.yml')
-        compose_file = os.path.join(self._temp_dir, 'docker-compose.yml')
 
         version_file = os.path.join(self._temp_dir, 'version')
         settings_file = os.path.join(self._temp_dir, 'settings.default.yml')
@@ -163,13 +212,7 @@ class AppBuildCommand(CliCommand):
         with open(version_file, 'w') as f:
             f.write(version)
 
-        # Generate compose file with 'app.yml', and without the 'platform' line for older AuterionOS
-        with open(compose_file, 'r') as fi:
-            lines = fi.readlines()
-        with open(app_file, 'w') as fo:
-            for line in lines:
-                if 'platform:' not in line and 'build:' not in line:
-                    fo.write(line)
+        self._generate_legacy_app_file(meta, app_file)
 
         pathlib.Path(settings_file).touch()
 
