@@ -49,7 +49,8 @@ def ensure_mender_artifact(artifact_path):
             _download_file('https://downloads.mender.io/mender-artifact/3.9.0/darwin/mender-artifact', artifact_path)
         else:
             error(f'Error: Platform {sys.platform} not supported. No available mender artifact.')
-    except:
+    except Exception as e:
+        print(e, file=sys.stderr)
         error('Failed to download mender artifact. Retry later.')
 
     os.chmod(artifact_path, 755)
