@@ -12,5 +12,8 @@ class CliCommand:
     def run(self, args):
         raise NotImplemented
 
+    def needs_device(self, args):
+        return True
+
     def handle_exception(self, exception: Exception):
         raise exception
